// $Id: RoundedRegion.cpp,v 1.2 2009/09/09 02:29:37 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file    RoundedRegion.cpp
  \brief   rounded QRegion based on a rect
  \author  Hugo Pereira
  \version $Revision: 1.2 $
  \date    $Date: 2009/09/09 02:29:37 $
*/


#include "RoundedRegion.h"

//_________________________________________________________
RoundedRegion::RoundedRegion( QRect rect, unsigned int corners ):
  QRegion( rect )
{

  // top left
  if( corners & TOP_LEFT )
  {
    const QPoint& point( rect.topLeft() );
    *this -= QRegion(point.x(), point.y()+0, 5, 1);
    *this -= QRegion(point.x(), point.y()+1, 3, 1);
    *this -= QRegion(point.x(), point.y()+2, 2, 1);
    *this -= QRegion(point.x(), point.y()+3, 1, 2);
  }

  // top right
  if( corners & TOP_RIGHT )
  {
    const QPoint& point( rect.topRight() );
    *this -= QRegion(point.x()-4, point.y()+0, 5, 1);
    *this -= QRegion(point.x()-2, point.y()+1, 3, 1);
    *this -= QRegion(point.x()-1, point.y()+2, 2, 1);
    *this -= QRegion(point.x()-0, point.y()+3, 1, 2);
  }

  // bottom left
  if( corners & BOTTOM_LEFT )
  {
    const QPoint& point( rect.bottomLeft() );
    *this -= QRegion(point.x(), point.y()-0, 5, 1);
    *this -= QRegion(point.x(), point.y()-1, 3, 1);
    *this -= QRegion(point.x(), point.y()-2, 2, 1);
    *this -= QRegion(point.x(), point.y()-4, 1, 2);
  }


  // bottom right
  if( corners & BOTTOM_RIGHT )
  {
    const QPoint& point( rect.bottomRight() );
    *this -= QRegion(point.x()-4, point.y()-0, 5, 1);
    *this -= QRegion(point.x()-2, point.y()-1, 3, 1);
    *this -= QRegion(point.x()-1, point.y()-2, 2, 1);
    *this -= QRegion(point.x()-0, point.y()-4, 1, 2);
  }

}
